@@ -17,10 +17,10 @@ function(coord){
   print("****                                                     ****");
   print("*************************************************************");
 	
-  print(paste("SPHERICAL STANDARD ERROR = ",sphericalErros));
+  print(paste("COLATITUDE = ",m_direction[1],", LONGITUDE = ",m_direction[2]));
   print(paste("MEAN MODULE = ",m_module));
   print(paste("CONCENTRATION PARAMETER = ",vm_parameter));
-  print(paste("COLATITUDE = ",m_direction[1],", LATITUDE = ",m_direction[2]));
-  }
+  print(paste("SPHERICAL STANDARD ERROR = ",sphericalErros));
+}
 
 
